==> core-react-0.8.0.tgz: package/es/Modal/ModalHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var ModalHeader = function ModalHeader(props, context) {
  var children = props.children,
      className = props.className,
      title = props.title,
      other = _objectWithoutProperties(props, ["children", "className", "title"]);

  return React.createElement("div", _extends({
    className: cx("".concat("waui", "-modal__modal-header"), className)
  }, other), title && React.createElement("div", {
    className: "".concat("waui", "-modal__modal-header_default")
  }, title), children);
};

ModalHeader.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** 导航栏标题，可以置空 */
  title: PropTypes.string
};
export default ModalHeader;

==> core-react-0.8.2.tgz: package/es/Modal/ModalHeader.js <==
function _extends() { _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; }; return _extends.apply(this, arguments); }

function _objectWithoutProperties(source, excluded) { if (source == null) return {}; var target = _objectWithoutPropertiesLoose(source, excluded); var key, i; if (Object.getOwnPropertySymbols) { var sourceSymbolKeys = Object.getOwnPropertySymbols(source); for (i = 0; i < sourceSymbolKeys.length; i++) { key = sourceSymbolKeys[i]; if (excluded.indexOf(key) >= 0) continue; if (!Object.prototype.propertyIsEnumerable.call(source, key)) continue; target[key] = source[key]; } } return target; }

function _objectWithoutPropertiesLoose(source, excluded) { if (source == null) return {}; var target = {}; var sourceKeys = Object.keys(source); var key, i; for (i = 0; i < sourceKeys.length; i++) { key = sourceKeys[i]; if (excluded.indexOf(key) >= 0) continue; target[key] = source[key]; } return target; }

import React from 'react';
import PropTypes from 'prop-types';
import cx from 'classnames';

var ModalHeader = function ModalHeader(props, context) {
  var children = props.children,
      className = props.className,
      title = props.title,
      other = _objectWithoutProperties(props, ["children", "className", "title"]);

  return (/*#__PURE__*/React.createElement("div", _extends({
      className: cx("".concat("waui", "-modal__modal-header"), className)
    }, other), title && /*#__PURE__*/React.createElement("div", {
      className: "".concat("waui", "-modal__modal-header_default")
    }, title), children)
  );
};

ModalHeader.propTypes = {
  children: PropTypes.node,
  className: PropTypes.string,

  /** 导航栏标题，可以置空 */
  title: PropTypes.string
};
export default ModalHeader;
